package com.menagerie.ophelia.database.polycule

import android.util.Log
import androidx.lifecycle.LiveData
import androidx.lifecycle.asLiveData
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.BioDao
import com.menagerie.ophelia.database.polycule.entity.Polycule
import com.menagerie.ophelia.database.polycule.entity.PolyculeDao
import com.menagerie.ophelia.database.polycule.entity.PolyculeWithBios
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.count

class PolyculeRepository(
    private val bioDao: BioDao,
    private val polyculeDao: PolyculeDao,
) {
    suspend fun upsertBio(bio: Bio) {
        bioDao.upsert(bio)
    }

    fun getBio(bioId: Long): Flow<Bio> {
        return bioDao.getBio(bioId)
    }

    fun getAllBios(): Flow<List<Bio>> {
        return bioDao.getAllBios()
    }

    suspend fun deleteBio(bio: Bio) {
        bioDao.delete(bio)
    }

    ///POLYCULES
    suspend fun upsertPolycule(polycule: Polycule) {
        polyculeDao.upsert(polycule)
    }

    fun getPolycule(id: Long): Flow<Polycule> {
        return polyculeDao.getPolycule(polyculeId = id)
    }

    fun getAllPolycules(): Flow<List<Polycule>> {
        return polyculeDao.getAllPolycules()
    }

    fun deletePolycule(polycule: Polycule) {
        polyculeDao.delete(polycule = polycule)
    }

    fun getPolyculeBios(): LiveData<List<PolyculeWithBios>> {
       return polyculeDao.getPolyculesWithBios()
    }
}