package com.menagerie.ophelia.database.polycule.entity.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.asLiveData
import androidx.lifecycle.viewModelScope
import com.menagerie.ophelia.database.polycule.PolyculeDatabaseManager
import com.menagerie.ophelia.database.polycule.entity.Polycule
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.launch

class PolyculeViewModel : ViewModel() {

    val allPolycules: LiveData<List<Polycule>> =
        PolyculeDatabaseManager.polyculeRepository.getAllPolycules().asLiveData()

    fun upsert(polycule: Polycule) = viewModelScope.launch {
        PolyculeDatabaseManager.polyculeRepository.upsertPolycule(polycule)
    }

    fun delete(polycule: Polycule) = viewModelScope.launch {
        PolyculeDatabaseManager.polyculeRepository.deletePolycule(polycule)
    }

    fun getPolycule(id: Long) = PolyculeDatabaseManager.polyculeRepository.getPolycule(id).asLiveData()

    fun getBios() = PolyculeDatabaseManager.polyculeRepository.getPolyculeBios()

    class PolyculeViewModelFactory() :
        ViewModelProvider.Factory {
        override fun <T : ViewModel> create(modelClass: Class<T>): T {
            if (modelClass.isAssignableFrom(PolyculeViewModel::class.java)) {
                @Suppress("UNCHECKED_CAST")
                return PolyculeViewModel() as T
            }
            throw IllegalArgumentException("Unknown ViewModel Class")
        }
    }
}

class InputPolyculeViewModel : ViewModel() {
    private var _polycule: MutableLiveData<Polycule> = MutableLiveData(Polycule())
    var polycule: LiveData<Polycule> = _polycule
    fun onNameChange(name: String) {
        polycule.value?.polyculeName ?: name
    }
}

class PolyculeDetailViewModel(
    id: Long
) : ViewModel() {
    var polycule = PolyculeDatabaseManager.polyculeRepository.getPolycule(id).asLiveData()
}