package com.menagerie.ophelia.view

import android.content.res.Configuration
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.menagerie.ophelia.R
import com.menagerie.ophelia.database.polycule.entity.Polycule
import com.menagerie.ophelia.database.polycule.entity.viewmodel.PolyculeViewModel
import com.menagerie.ophelia.ui.theme.OpheliaTheme

@Composable
fun HomeScreen(
    onClick: (Boolean) -> Unit,

) {
    val newUser = false

    val text = if(newUser) R.string.welcome else R.string.welcome_back
    HeaderText(text) {
        onClick(newUser)
    }
}

@Composable
fun HeaderText(
    text: Int,
    onClick: () -> Unit
) {
    Box(
        modifier = Modifier
            .fillMaxSize()
    ) {
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 10.dp)
                .align(Alignment.Center),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center,
        ) {
            Spacer(modifier = Modifier.weight(1f))
            Text(
                text = stringResource(id = R.string.app_name),
                style = MaterialTheme.typography.displayLarge
            )
            Text(
                text = stringResource(id = R.string.app_tag)
            )
            Spacer(modifier = Modifier.weight(1f))
            Button(
                modifier = Modifier.padding(12.dp),
                onClick = onClick
            ) {
                Text(text = stringResource(id = text))
            }
        }
    }
}


@Preview(showBackground = true,
    uiMode = Configuration.UI_MODE_NIGHT_NO or Configuration.UI_MODE_TYPE_NORMAL, )
@Composable
fun HomeScreenPreview(){
    OpheliaTheme {
        Surface {
            HomeScreen() {}
        }
    }
}