package com.menagerie.ophelia.view.polycule

import android.util.Log
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.statusBarsPadding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.FloatingActionButton
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.material3.TopAppBarScrollBehavior
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.lifecycle.viewmodel.compose.viewModel
import com.menagerie.ophelia.database.polycule.entity.Bio
import com.menagerie.ophelia.database.polycule.entity.viewmodel.PolyculeViewModel
import com.menagerie.ophelia.view.biographies.BioCardList

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PolyculeHomeView(
    modifier: Modifier = Modifier,
    polyculeId: Long,
    onBioClick: (Bio) -> Unit = {},
    onAddClick: () -> Unit,
) {
    val scrollBehavior = TopAppBarDefaults.enterAlwaysScrollBehavior()
    val mPolyculeViewModel: PolyculeViewModel = viewModel(
        factory = PolyculeViewModel.PolyculeViewModelFactory()
    )
    val polycule = mPolyculeViewModel.getPolycule(polyculeId)
    Log.d("Tawni", "i")

    polycule.value?.let {

        val items = mPolyculeViewModel.getBios().value?.get(polyculeId.toInt())?.bios

        items?.let {

            Scaffold(
                modifier = modifier,
                bottomBar = {
                    PolyculeTopAppBar(
                        onFilterClick = { },
                        scrollBehavior = scrollBehavior
                    )
                }
            ) {
                Text(
                    text = polycule.value!!.polyculeName,
                    style = MaterialTheme.typography.headlineLarge
                )
                PolyculeHomeScreen(
                    onBioClick = onBioClick,
                    onAddClick = onAddClick,
                    modifier = modifier.padding(it),
                    items = items,
                )
            }
        }
    }
}

@Composable
fun PolyculeHomeScreen(
    onBioClick: (Bio) -> Unit,
    onAddClick: () -> Unit = {},
    modifier: Modifier,
    items: List<Bio>,
) {

    Column(
        modifier = modifier
    ) {
        BioCardList(bioList = items, onBioClick = onBioClick)
        FloatingActionButton(
            onClick = onAddClick
        ) {
            Icon(Icons.Filled.Add, "Add Bio")
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PolyculeTopAppBar(
    onFilterClick: () -> Unit,
    modifier: Modifier = Modifier,
    scrollBehavior: TopAppBarScrollBehavior,
) {
    TopAppBar(
        title = {
            Row(
                Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.Center,
            ) {
            }
        },
        modifier = modifier.statusBarsPadding(),
        actions = {},
        scrollBehavior = scrollBehavior
    )
}